@@ -91,7 +91,7 @@ impl From<Image> for NSTDImage {
 /// Returns: `NSTDImage image` - The image.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_image_open(file_name: *const c_char) -> NSTDImage {
+pub unsafe extern "C" fn nstd_image_open(file_name: *const c_char) -> NSTDImage {
     match CStr::from_ptr(file_name).to_str() {
         Ok(file_name) => match image::open(file_name) {
             Ok(image) => NSTDImage::from(image),
@@ -107,7 +107,7 @@ pub unsafe extern "C" fn nstd_std_image_open(file_name: *const c_char) -> NSTDIm
 /// Returns: `NSTDImage image` - The image.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_image_load(bytes: &NSTDSlice) -> NSTDImage {
+pub unsafe extern "C" fn nstd_image_load(bytes: &NSTDSlice) -> NSTDImage {
     if bytes.element_size == 1 {
         match image::load_from_memory(bytes.as_byte_slice()) {
             Ok(image) => return NSTDImage::from(image),
@@ -122,7 +122,7 @@ pub unsafe extern "C" fn nstd_std_image_load(bytes: &NSTDSlice) -> NSTDImage {
 ///     `NSTDImage *image` - Pointer to the image data.
 #[inline]
 #[cfg_attr(feature = "clib", no_mangle)]
-pub unsafe extern "C" fn nstd_std_image_free(image: &mut NSTDImage) {
+pub unsafe extern "C" fn nstd_image_free(image: &mut NSTDImage) {
     Box::from_raw(image.image);
     image.image = ptr::null_mut();
 }
